Learn R Programming

ANSM5 (version 1.1.1)

blomqvist: Calculate Blomqvist coefficient

Description

blomqvist() calculates the Blomqvist coefficient and is used in chapter 10 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

blomqvist(
  x,
  y,
  alternative = c("two.sided", "less", "greater"),
  max.exact.cases = 1000,
  nsims.mc = 1e+05,
  seed = NULL,
  do.exact = TRUE,
  do.mc = FALSE
)

Value

An ANSMstat object with the results from applying the function

Arguments

x

Numeric vector of same length as y

y

Numeric vector of same length as x

alternative

Type of alternative hypothesis (defaults to two.sided)

max.exact.cases

Maximum number of cases allowed for exact calculations (defaults to 1000)

nsims.mc

Number of Monte Carlo simulations to be performed (defaults to 100000)

seed

Random number seed to be used for Monte Carlo simulations (defaults to NULL)

do.exact

Boolean indicating whether or not to perform exact calculations (defaults to TRUE)

do.mc

Boolean indicating whether or not to perform Monte Carlo calculations (defaults to FALSE)

Examples

Run this code
# Example 10.9 from "Applied Nonparametric Statistical Methods" (5th edition)
blomqvist(ch10$q1, ch10$q2, alternative = "greater")

# Exercise 10.7 from "Applied Nonparametric Statistical Methods" (5th edition)
blomqvist(ch10$ERA, ch10$SSS)

Run the code above in your browser using DataLab