Learn R Programming

ANSM5 (version 1.1.1)

bowker: Perform Bowker's extension of McNemar's test

Description

bowker() performs the Bowker's extension of McNemar's test and is used in chapter 12 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

bowker(x, y = NULL, do.asymp = TRUE)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Factor of same length as y, or two-dimensional square table

y

Factor of same length as x (or NULL if x is table) (defaults to NULL)

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to TRUE)

Examples

Run this code
# Example 12.12 from "Applied Nonparametric Statistical Methods" (5th edition)
bowker(ch12$side.effect.new, ch12$side.effect.old)

# Exercise 12.12 from "Applied Nonparametric Statistical Methods" (5th edition)
bowker(ch12$first.response, ch12$second.response)

Run the code above in your browser using DataLab