Learn R Programming

ANSM5 (version 1.1.1)

breslow.day: Perform Breslow and Day test

Description

breslow.day() performs the Breslow and Day test and is used in chapter 13 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

breslow.day(x, y, z, CI.width = 0.95, do.asymp = TRUE, do.CI = TRUE)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Binary factor of same length as y, z

y

Binary factor of same length as x, z

z

Factor of same length as x, y

CI.width

Confidence interval width (defaults to 0.95)

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to TRUE)

do.CI

Boolean indicating whether or not to perform confidence interval calculations (defaults to TRUE)

Examples

Run this code
# Example 13.3 from "Applied Nonparametric Statistical Methods" (5th edition)
breslow.day(ch13$machine, ch13$output.status, ch13$material.source)

# Exercise 13.7 from "Applied Nonparametric Statistical Methods" (5th edition)
breslow.day(ch13$medicine, ch13$response, ch13$location)

Run the code above in your browser using DataLab