Learn R Programming

ANSM5 (version 1.1.1)

cramer.von.mises: Perform Cramer-von Mises test

Description

cramer.von.mises() performs the Cramer-von Mises test and is used in chapter 6 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

cramer.von.mises(x, y, alternative = c("two.sided", "less", "greater"))

Value

An ANSMtest object with the results from applying the function

Arguments

x

Numeric vector

y

Numeric vector

alternative

Type of alternative hypothesis (defaults to two.sided)

Examples

Run this code
# Example 6.16 from "Applied Nonparametric Statistical Methods" (5th edition)
cramer.von.mises(ch6$salivaF, ch6$salivaM)
cramer.von.mises(ch6$salivaF, ch6$salivaM, alternative = "greater")

Run the code above in your browser using DataLab