Learn R Programming

ANSM5 (version 1.1.1)

friedman.lsd: Perform Least Significant Differences test after the Friedman test

Description

friedman.lsd() performs the Least Significant Differences test after the Friedman test and is used in chapter 8 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

friedman.lsd(y, groups, blocks, ids)

Value

An ANSMtest object with the results from applying the function

Arguments

y

Numeric vector of same length as groups, blocks

groups

Factor of same length as y, blocks with levels such that length(y) == nlevels(groups) * nlevels(blocks)

blocks

Factor of same length as y, groups with levels such that length(y) == nlevels(groups) * nlevels(blocks)

ids

Vector of length 2 with elements both levels of groups

Examples

Run this code
# Example 8.11 from "Applied Nonparametric Statistical Methods" (5th edition)
friedman.lsd(ch8$prey.preference, ch8$prey, ch8$larva, c("Cyclops", "Anopheles"))

#  from "Applied Nonparametric Statistical Methods" (5th edition)

Run the code above in your browser using DataLab