Learn R Programming

ANSM5 (version 1.1.1)

hettmansperger.elmore: Perform Hettmansperger and Elmore interaction test

Description

hettmansperger.elmore() performs the Hettmansperger and Elmore interaction test and is used in chapter 8 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

hettmansperger.elmore(
  y,
  factor.a,
  factor.b,
  nsims.mc = 1000,
  seed = NULL,
  do.asymp = TRUE,
  do.mc = FALSE,
  median.polish = FALSE
)

Value

An ANSMtest object with the results from applying the function

Arguments

y

Numeric vector of same length as factor.a, factor.b

factor.a

Factor of same length as y, factor.b

factor.b

Factor of same length as y, factor.a

nsims.mc

Number of Monte Carlo simulations to be performed (defaults to 1000)

seed

Random number seed to be used for Monte Carlo simulations (defaults to NULL)

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to TRUE)

do.mc

Boolean indicating whether or not to perform Monte Carlo calculations (defaults to FALSE)

median.polish

Boolean indicating whether or not to use median polish (defaults to FALSE)

Examples

Run this code
# Example 8.6 from "Applied Nonparametric Statistical Methods" (5th edition)
hettmansperger.elmore(ch8$plant.weight.2, ch8$growth.hormone, ch8$undersoil.heating)

# Exercise 8.3 from "Applied Nonparametric Statistical Methods" (5th edition)
hettmansperger.elmore(ch8$game.time, ch8$experience, ch8$game)

Run the code above in your browser using DataLab