Learn R Programming

ANSM5 (version 1.1.1)

kendall.concordance: Calculate Kendall's concordance

Description

kendall.concordance() calculates Kendall's concordance and is used in chapter 10 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

kendall.concordance(
  y,
  groups,
  blocks,
  max.exact.perms = 1e+05,
  nsims.mc = 1e+05,
  seed = NULL,
  do.asymp = FALSE,
  do.exact = TRUE
)

Value

An ANSMstat object with the results from applying the function

Arguments

y

Numeric vector of same length as groups, blocks

groups

Factor of same length as y, blocks with levels such that length(y) == nlevels(groups) * nlevels(blocks)

blocks

Factor of same length as y, groups with levels such that length(y) == nlevels(groups) * nlevels(blocks)

max.exact.perms

Maximum number of permutations allowed for exact calculations (defaults to 100000)

nsims.mc

Number of Monte Carlo simulations to be performed (defaults to 10000)

seed

Random number seed to be used for Monte Carlo simulations (defaults to NULL)

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to FALSE)

do.exact

Boolean indicating whether or not to perform exact calculations (defaults to TRUE)

Examples

Run this code
# Exercise 10.11 from "Applied Nonparametric Statistical Methods" (5th edition)
kendall.concordance(ch10$marks, ch10$script, ch10$examiner, do.exact = FALSE, do.asymp = TRUE)
kendall.concordance(ch10$marks, ch10$examiner, ch10$script, do.exact = FALSE, do.asymp = TRUE)

Run the code above in your browser using DataLab