Learn R Programming

ANSM5 (version 1.1.1)

kruskal.wallis.lsd: Perform Least Significant Differences test after the Kruskal-Wallis test

Description

kruskal.wallis.lsd() performs the Least Significant Differences test after the Kruskal-Wallis test and is used in chapter 8 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

kruskal.wallis.lsd(x, g, ids)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Numeric vector of same length as g

g

Factor of same length as x

ids

Vector of length 2 with elements both levels of g

Examples

Run this code
# Example 8.10 from "Applied Nonparametric Statistical Methods" (5th edition)
kruskal.wallis.lsd(ch8$sentences, ch8$authors, c("Vulliamy", "Queen"))

# Exercise 8.8 from "Applied Nonparametric Statistical Methods" (5th edition)
kruskal.wallis.lsd(ch8$seizure.score, ch8$hospital, c("HospitalA", "HospitalC"))

Run the code above in your browser using DataLab