Learn R Programming

ANSM5 (version 1.1.1)

lilliefors: Performs Lilliefors test of Normality

Description

lilliefors() performs Lilliefors test of Normality and is used in chapters 4, 5 and 6 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

lilliefors(x, alternative = c("two.sided"), nsims.mc = 10000, seed = NULL)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Numeric vector

alternative

Type of alternative hypothesis (defaults to c("two.sided"))

nsims.mc

Number of Monte Carlo simulations to be performed (defaults to 10000)

seed

Random number seed to be used for Monte Carlo simulations (defaults to NULL)

Examples

Run this code
# Example 4.4 from "Applied Nonparametric Statistical Methods" (5th edition)
lilliefors(ch4$ages, seed = 1)

# Exercise 6.15 from "Applied Nonparametric Statistical Methods" (5th edition)
lilliefors(ch6$doseI.2, seed = 1, nsims = 1000)

Run the code above in your browser using DataLab