Learn R Programming

ANSM5 (version 1.1.1)

mantel.haenszel: Perform Mantel-Haenszel test

Description

mantel.haenszel() performs the Mantel-Haenszel test and is used in chapter 13 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

mantel.haenszel(x, y, z, do.asymp = TRUE)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Binary factor of same length as y, z

y

Binary factor of same length as x, z

z

Factor of same length as x, y

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to TRUE)

Examples

Run this code
# Example 13.4 from "Applied Nonparametric Statistical Methods" (5th edition)
mantel.haenszel(ch13$drug, ch13$side.effects, ch13$age.group)

#  from "Applied Nonparametric Statistical Methods" (5th edition)

Run the code above in your browser using DataLab