powered by
mood() performs the Mood test and is used in chapter 6 of "Applied Nonparametric Statistical Methods" (5th edition)
mood()
mood( x, y, H0 = NULL, alternative = c("two.sided", "less", "greater"), max.exact.cases = 25, do.asymp = FALSE, do.exact = TRUE )
An ANSMtest object with the results from applying the function
Numeric vector
Null hypothesis value (defaults to NULL)
NULL
Type of alternative hypothesis (defaults to two.sided)
two.sided
Maximum number of cases allowed for exact calculations (defaults to 25)
25
Boolean indicating whether or not to perform asymptotic calculations (defaults to FALSE)
FALSE
Boolean indicating whether or not to perform exact calculations (defaults to TRUE)
TRUE
# Example 6.12 from "Applied Nonparametric Statistical Methods" (5th edition) mood(ch6$typeA, ch6$typeB) mood(ch6$typeA, ch6$typeB, do.exact = FALSE, do.asymp = TRUE)
Run the code above in your browser using DataLab