Learn R Programming

ANSM5 (version 1.1.1)

moses.extreme.reactions: Perform Moses test for extreme reactions

Description

moses.extreme.reactions() performs the Moses test for extreme reactions and is used in chapter 6 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

moses.extreme.reactions(
  x,
  y,
  H0 = NULL,
  max.exact.cases = 1000,
  do.exact = TRUE
)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Numeric vector

y

Numeric vector

H0

Null hypothesis value (defaults to NULL)

max.exact.cases

Maximum number of cases allowed for exact calculations (defaults to 1000)

do.exact

Boolean indicating whether or not to perform exact calculations (defaults to TRUE)

Examples

Run this code
# Example 6.14 from "Applied Nonparametric Statistical Methods" (5th edition)
moses.extreme.reactions(ch6$groupI.amended, ch6$groupII)
moses.extreme.reactions(ch6$groupI.amended, ch6$groupII)

Run the code above in your browser using DataLab