Learn R Programming

ANSM5 (version 1.1.1)

normal.scores.test: Perform Normal Scores test

Description

normal.scores.test() performs the Normal Scores test and is used in chapters 6 and 8 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

normal.scores.test(
  x,
  y,
  H0 = NULL,
  alternative = c("two.sided", "less", "greater"),
  max.exact.cases = 25,
  do.asymp = FALSE,
  do.exact = TRUE
)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Numeric vector

y

Numeric vector

H0

Null hypothesis value (defaults to NULL)

alternative

Type of alternative hypothesis (defaults to two.sided)

max.exact.cases

Maximum number of cases allowed for exact calculations (defaults to 25)

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to FALSE)

do.exact

Boolean indicating whether or not to perform exact calculations (defaults to TRUE)

Examples

Run this code
# Example 5.8 from "Applied Nonparametric Statistical Methods" (5th edition)
normal.scores.test(ch6$groupA, ch6$groupB, do.exact = FALSE, do.asymp = TRUE)

# Exercise 6.15 from "Applied Nonparametric Statistical Methods" (5th edition)
normal.scores.test(ch6$doseI, ch6$doseII)

Run the code above in your browser using DataLab