Learn R Programming

ANSM5 (version 1.1.1)

runs.ncat: Perform Runs test for three or more categories

Description

runs.ncat() performs the Runs test for three or more categories and is used in chapters 4 and 7 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

runs.ncat(
  x,
  alternative = c("two.sided", "less", "greater"),
  cont.corr = TRUE,
  nsims.mc = 1e+05,
  seed = NULL,
  do.asymp = TRUE,
  do.mc = FALSE
)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Vector or factor

alternative

Type of alternative hypothesis (defaults to two.sided)

cont.corr

Boolean indicating whether or not to use continuity correction (defaults to TRUE)

nsims.mc

Number of Monte Carlo simulations to be performed (defaults to 100000)

seed

Random number seed to be used for Monte Carlo simulations (defaults to NULL)

do.asymp

Boolean indicating whether or not to perform asymptotic calculations (defaults to TRUE)

do.mc

Boolean indicating whether or not to perform Monte Carlo calculations (defaults to FALSE)

Examples

Run this code
# Example 4.15 from "Applied Nonparametric Statistical Methods" (5th edition)
runs.ncat(ch4$births, alternative = "less")

# Exercise 7.16 from "Applied Nonparametric Statistical Methods" (5th edition)
runs.ncat(ch7$regions[order(ch7$affordability)], alternative = "less")

Run the code above in your browser using DataLab