Learn R Programming

ANSM5 (version 1.1.1)

shapirotest.ANSM: Perform Shapiro-Wilk test of Normality

Description

shapirotest.ANSM() is a wrapper for shapiro.test() from the stats package - performs the Shapiro-Wilk test of Normality and is used in chapters 4 and 5 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

shapirotest.ANSM(x, alternative = c("two.sided"))

Value

An ANSMtest object with the results from applying the function

Arguments

x

Numeric vector

alternative

Type of alternative hypothesis (defaults to c("two.sided"))

Examples

Run this code
# Example 4.4 from "Applied Nonparametric Statistical Methods" (5th edition)
shapirotest.ANSM(ch4$ages)

# Example 5.3 from "Applied Nonparametric Statistical Methods" (5th edition)
shapirotest.ANSM(ch5$bp.incorrect)

Run the code above in your browser using DataLab