Learn R Programming

ANSM5 (version 1.1.1)

zelen: Perform Zelen test

Description

zelen() performs the Zelen test and is used in chapter 13 of "Applied Nonparametric Statistical Methods" (5th edition)

Usage

zelen(x, y, z, max.exact.perms = 1e+06, do.exact = TRUE)

Value

An ANSMtest object with the results from applying the function

Arguments

x

Binary factor of same length as y, z

y

Binary factor of same length as x, z

z

Factor of same length as x, y

max.exact.perms

Maximum number of permutations allowed for exact calculations (defaults to 1000000)

do.exact

Boolean indicating whether or not to perform exact calculations (defaults to TRUE)

Examples

Run this code
# Section 13.2.5 from "Applied Nonparametric Statistical Methods" (5th edition)
zelen(ch13$drug, ch13$side.effects, ch13$age.group)

# Example 13.3 from "Applied Nonparametric Statistical Methods" (5th edition)
zelen(ch13$machine, ch13$output.status, ch13$material.source)

Run the code above in your browser using DataLab