powered by
cramer.von.mises() performs the Cramer-von Mises test and is used in chapter 6 of "Applied Nonparametric Statistical Methods" (5th edition)
cramer.von.mises()
cramer.von.mises(x, y, alternative = c("two.sided", "less", "greater"))
An ANSMtest object with the results from applying the function
Numeric vector
Type of alternative hypothesis (defaults to two.sided)
two.sided
# Example 6.16 from "Applied Nonparametric Statistical Methods" (5th edition) cramer.von.mises(ch6$salivaF, ch6$salivaM) cramer.von.mises(ch6$salivaF, ch6$salivaM, alternative = "greater")
Run the code above in your browser using DataLab