powered by
moses.extreme.reactions() performs the Moses test for extreme reactions and is used in chapter 6 of "Applied Nonparametric Statistical Methods" (5th edition)
moses.extreme.reactions()
moses.extreme.reactions( x, y, H0 = NULL, max.exact.cases = 1000, do.exact = TRUE )
An ANSMtest object with the results from applying the function
Numeric vector
Null hypothesis value (defaults to NULL)
NULL
Maximum number of cases allowed for exact calculations (defaults to 1000)
1000
Boolean indicating whether or not to perform exact calculations (defaults to TRUE)
TRUE
# Example 6.14 from "Applied Nonparametric Statistical Methods" (5th edition) moses.extreme.reactions(ch6$groupI.amended, ch6$groupII) moses.extreme.reactions(ch6$groupI.amended, ch6$groupII)
Run the code above in your browser using DataLab